from rest_framework import viewsets
from rest_framework.response import Response

from .serializers import CategoryWithPosterSerializer as CategorySerializer
from .utils import get_categories_tree


class CategoryViewSet(viewsets.ViewSet):
    def list(self, request):
        categories_tree = get_categories_tree(request, join_posters=True)
        return Response(
            CategorySerializer(
                categories_tree,
                context={"request": request},
                many=True,
            ).data
        )



# Generated by Django 1.11.5 on 2017-10-07 14:32
import django.db.models.deletion
import django.utils.timezone
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("misago_categories", "0006_moderation_queue_roles"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("misago_threads", "0006_redo_partial_indexes"),
        ("misago_readtracker", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="PostRead",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "last_read_on",
                    models.DateTimeField(default=django.utils.timezone.now),
                ),
                (
                    "category",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="misago_categories.Category",
                    ),
                ),
                (
                    "post",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="misago_threads.Post",
                    ),
                ),
                (
                    "thread",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="misago_threads.Thread",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
        )
    ]



from django.db import migrations, models

from ..models import permissions_default


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Role",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                ("name", models.CharField(max_length=255)),
                (
                    "special_role",
                    models.CharField(max_length=255, null=True, blank=True),
                ),
                ("permissions", models.JSONField(default=permissions_default)),
            ],
            options={"abstract": False},
            bases=(models.Model,),
        )
    ]
